@@ -8,9 +8,17 @@ import unittest
 
 from junitxml.tests import (
     test_junitxml,
+    test_main,
+    test_runner
     )
 
 def test_suite():
     return unittest.TestLoader().loadTestsFromNames([
         'junitxml.tests.test_junitxml',
+        'junitxml.tests.test_main',
+        'junitxml.tests.test_runner'
         ])
+
+if __name__ == '__main__':
+    suite = test_suite()
+    unittest.TextTestRunner(verbosity=2).run(suite)
